# Distributed under the OSI-approved BSD 2-Clause License.  See accompanying
# file Copyright.txt or https://cmake.org/licensing for details.
# Copyright (c) 2020 Pavel "Malo" Skrylev <majioa@yandex.ru>
#
#[=======================================================================[.rst:
KGraph

Find KGraph include folders and libraries

Use as follows:

find_library(KGraph)

This module finds headers and requested component libraries. For the former
case results are reported in variables:

   KGRAPH_FOUND             - True if headers and requested libraries were found
   KGRAPH_INCLUDE_DIR       - KGraph include directories
   KGRAPH_LIBRARY           - KGraph link library

This module reads hints about search locations from variables:

   KGRAPH_ROOT_HINTS        - Preferred installation prefix
   KGRAPH_INCLUDE_DIR_HINTS - Preferred include directory e.g. <prefix>/include

   Example to find KGraph headers only:

   find_package(KGraph)
   if(KGRAPH_FOUND)
      include_directories(${KGRAPH_INCLUDE_DIR})
      link_libraries(${KGRAPH_LIBRARY})
   endif()

#]=======================================================================]

if(NOT KGRAPH_INCLUDE_DIR)
   find_path(KGRAPH_INCLUDE_DIR
      NAMES
         kgraph.h
      HINTS
         ENV KGRAPH_INCLUDE_DIR_HINTS
         ENV KGRAPH_ROOT_HINT
      PATHS
         ${CMAKE_INSTALL_PREFIX}/include
      PATH_SUFFIXES
         kgraph
   )

   find_library(KGRAPH_LIBRARY NAMES kgraph)
endif(NOT KGRAPH_INCLUDE_DIR)

if(KGRAPH_INCLUDE_DIR AND KGRAPH_LIBRARY)
   set(KGRAPH_FOUND TRUE)

   message(STATUS "KGraph found (headers in ${KGRAPH_INCLUDE_DIR}, and library is ${KGRAPH_LIBRARY})")

   mark_as_advanced(KGRAPH_INCLUDE_DIR)
   mark_as_advanced(KGRAPH_LIBRARY)
endif()
